@@ -18,7 +18,6 @@ from multiprocessing import current_process
 from functools import partial
 from numpy import linalg as LA
 import sigProfilerPlotting as plot
-# from SigProfilerExtractor import PlotDecomposition as sp
 from sigProfilerPlotting import plotActivity as plot_ac
 from sigProfilerPlotting import tmbplot as tmb
 import string 
@@ -1399,27 +1398,4 @@ def custom_signatures_plot(signatures, output):
             pdf.attach_note("signature plots")  
             pdf.savefig()
             plt.close()
-            
-
-# merge the decomposition plots
-def merge_pdf(input_folder, output_file):
-    pdf2merge = []
-    for filename in os.listdir(input_folder):
-        #print(filename)
-        if filename.endswith('.pdf'):
-            pdf2merge.append(filename)
-            
-    pdf2merge.sort()
-    pdfWriter = PyPDF2.PdfFileWriter()
-    for filename in pdf2merge:
-        pdfFileObj = open(input_folder+"/"+filename,'rb')
-        pdfReader = PyPDF2.PdfFileReader(pdfFileObj)
-        for pageNum in range(pdfReader.numPages):
-            pageObj = pdfReader.getPage(pageNum)
-            pdfWriter.addPage(pageObj)
-            
-    pdfOutput = open(output_file+'.pdf', 'wb')
-    pdfWriter.write(pdfOutput)
-    #Outputting the PDF
-    pdfOutput.close()
 
